# Generated by roxygen2: do not edit by hand

export(jgd)
export(jgd_begin_group)
export(jgd_discover)
export(jgd_end_group)
export(jgd_ext)
export(jgd_frame_ext)
export(jgd_server_info)
export(with_jgd_ext)
export(with_jgd_frame_ext)
export(with_jgd_group)
importFrom(grDevices,recordGraphics)
useDynLib(jgd, .registration = TRUE)
