% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/jgd.R
\name{jgd_begin_group}
\alias{jgd_begin_group}
\title{Begin a drawing group (experimental)}
\usage{
jgd_begin_group(ext = NULL)
}
\arguments{
\item{ext}{A single JSON string with extension fields for this group, or
\code{NULL} for a group without extension fields.}
}
\value{
Called for its side effect; returns \code{NULL} invisibly.
}
\description{
Emits a \code{beginGroup} operation into the drawing stream.  All subsequent
drawing operations until the matching \code{\link[=jgd_end_group]{jgd_end_group()}} are part of this
group.  The renderer may use the group's extension fields to apply effects
to the group as a whole.
}
\section{Lifecycle}{

\strong{Experimental.} This API may change in future versions.
}

