% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/jgd.R
\name{with_jgd_group}
\alias{with_jgd_group}
\title{Scoped drawing group (experimental)}
\usage{
with_jgd_group(ext, expr)
}
\arguments{
\item{ext}{A single JSON string with extension fields for this group, or
\code{NULL} for a group without extension fields.}

\item{expr}{Expression to evaluate within the group.}
}
\value{
The result of evaluating \code{expr}.
}
\description{
Opens a drawing group with extension fields, evaluates \code{expr}, then closes
the group on exit.
}
\section{Lifecycle}{

\strong{Experimental.} This API may change in future versions.
}

